raise UserWarning(
    "Using PyPi with pip is not a supported installation method for this project yet. In the meantime"
    "time please refer to the project README.md for details on how to install this project."
)
